\name{applera}
\docType{class}
\alias{applera-class}
\alias{apFilter,applera-method}
\alias{boxplot,applera-method}
\alias{ctrl,applera-method}
\alias{cvAp,applera-method}
\alias{flags,applera-method}
\alias{geneid,applera-method}
\alias{hist,applera-method}
\alias{iqrFilter,applera-method}
\alias{mvaAp,applera-method}
\alias{normLoess,applera-method}
\alias{normQuantile,applera-method}
\alias{organism,applera-method}
\alias{sdev,applera-method}
\alias{show,applera-method}
\alias{signal,applera-method}
\alias{sn,applera-method}
\alias{subExp,applera-method}
\alias{subGenes,applera-method}

\title{Class "applera" ~~~ }
\description{  This is class representation for Applera Microarray Data.}
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("applera",
                      Organism= ..., #Object of class character, 
		      Geneid= ..., #Object of class vector, 
		      Signal= ..., #Object of class exprSet, 
		      Sdev= ..., #Object of class exprSet, 
		      Cv= ..., #Object of class exprSet, 
                      Sn= ..., #Object of class exprSet,
		      Flags= ..., #Object of class exprSet, 
		      Ctrl= ..., #Object of class list.)}.
}
\section{Slots}{
  \describe{
    \item{\code{Organism}:}{Object of class \code{"character"} A string describing the organism implemented in the array: "Hs" for human, "Mm" for mouse, "Rn" for rat. }
    \item{\code{Geneid}:}{Object of class \code{"character"} A vector of primary Ids associated to spotted probes. }
    \item{\code{Signal}:}{Object of class \code{"exprSet"} it contains all the log2 chemiolominescence (CL) expression signals. The CL signal is normalized by the fluorescence (FL) signal over the feature integration aperture. See AB1700 manual. }
    \item{\code{Sdev}:}{Object of class \code{"exprSet"} An estimated measurement uncertainty of Normalized Signal. See ABI1700 manual. }
    \item{\code{Cv}:}{Object of class \code{"exprSet"} The fraction of uncertainty in the signal. Cv indicates the predicted spread of feature signal. See AB1700 manual. }
    \item{\code{Sn}:}{Object of class \code{"exprSet"} The ratio Signal/Sdev. S/N expresses the confidence of feature dectability. See AB1700 manual. }
    \item{\code{Flags}:}{Object of class \code{"exprSet"} A numeric code that identifies conditions for each feature. It allows to eliminate possibily problematic data. Features with flags greater than 100 might have quality issues. See AB1700 manual. }
    \item{\code{Ctrl}:}{Object of class \code{"list"} All controls spots values for Signal, Sdev, Cv, Sn and Flags. See ABI1700 manual. }
    \item{\code{exprs}:}{Object of class \code{"exprMatrix"} All data in slots Signal, Sdev, Cv, Sn and Flags are represented as exprSet object }
    \item{\code{se.exprs}:}{Object of class \code{"exprMatrix"} Not used }
    \item{\code{phenoData}:}{Object of class \code{"phenoData"} All data in slots Signal, Sdev, Cv, Sn and Flags contain the phenoData used to build the applera object}
    \item{\code{description}:}{Object of class \code{"characterORMIAME"} Not used }
    \item{\code{annotation}:}{Object of class \code{"character"} Not used }
    \item{\code{notes}:}{Object of class \code{"character"} Not used }
  }
}
\section{Extends}{
Class \code{"exprSet"}, directly.
}
\section{Methods}{
  \describe{
    \item{apFilter}{\code{signature(apObj = "applera")}: Function to filter an appleraSet by Sn or Flags}
    \item{boxplot}{\code{signature(x = "applera")}: Boxplot representation of slots data }
    \item{ctrl}{\code{signature(object = "applera")}: Function returning the list associated to the Ctrl slot }
    \item{cvAp}{\code{signature(object = "applera")}: Function returning the exprSet associated to the Cv slot }
    \item{flags}{\code{signature(object = "applera")}: Function returning the exprSet associated to the Flags slot }
    \item{geneid}{\code{signature(object = "applera")}: Function returning the Geneid slot }
    \item{hist}{\code{signature(x = "applera")}: Density distributions of slots data }
    \item{iqrFilter}{\code{signature(apObj = "applera")}: Function to filter an appleraSet, given a  specific IQR values. }
    \item{mvaAp}{\code{signature(apObj = "applera")}: mva.pairs representation of Signal slot data }
    \item{normLoess}{\code{signature(apObj = "applera")}: Function to normalize an appleraSet using the normalize.loess function of the affy package }
    \item{normQuantile}{\code{signature(apObj = "applera")}: Function to normalize an appleraSet using the normalize.quantile function of the affy package }
    \item{organism}{\code{signature(object = "applera")}: Function returning the Organism slot }
    \item{sdev}{\code{signature(object = "applera")}: Function returning the exprSet associated to the Sdev slot }
    \item{show}{\code{signature(object = "applera")}: Renders information about the appleraSet in a concise way on stdout }
    \item{signal}{\code{signature(object = "applera")}: Function returning the exprSet associated to the Signal slot }
    \item{sn}{\code{signature(object = "applera")}: Function returning the exprSet associated to the Sn slot }
    \item{subExp}{\code{signature(apObj = "applera")}: Function to subset an appleraSet given a vector of sampleNames }
    \item{subGenes}{\code{signature(apObj = "applera")}: Function to subset an appleraSet given a vector of geneNames }
  }
}
\references{}
\author{ Raffaele A. Calogero <raffaele.calogero@unito.it>; Francesca Cordero <fcordero@di.unito.it> }
\note{}
\seealso{
 \code{\link{readAp}}
}
\examples{

}
\keyword{classes}
