\name{optFilter}
\alias{optFilter}
\alias{optFilter}
\title{Function to optimize the integration of S/N filter with IQR filter}
\description{
  The function \code{optFilter}  optimizes filtering procedure for two classes experiment (e.g. untreated vs treated) using limma linear model analysis. The function needs an applera object, the covariate name allowing the separation of the data in two groups, a S/N value (see definition of Sn in applera-class help), a set of p conditions indicating the minimum percentage of experiments  characterized by a specific sn.value, a range of IQR values (see iqrFilter definition in applera-class help).
  When an applera object, characterized by a phenodata covariate allowing the separation in two groups, is passed to the function the set of user-defined filtering combinations based on S/N ratio and IQR values are generated and the filtered data stes are passed to the limma package. The output of the function is  the filtering combination that will produce the higher number of differentially expressed genes.
  The rationale of this approach is to reduce as much as possible the non-significative genes and to limit the number of genes passed to statistical tests. However, very stringent filtering might eliminate also many significative genes. This function try to find the best compromise to generate a filtered set of genes in which are removed low quality features (sn filter, see the snFilter defition in the applera-class help) and unchanged genes (iqrFilter will remove all genes with limited variation within the experiments)
 }
\usage{
optFilter(apObj, covariate , sn.value=3, p=c(1, 0.75, 0.5, 0.25), iqr.value=c(0.5, 0.25))
}
\arguments{
  \item{apObj}{an applera object}
  \item{covariate}{a phenodata covariate allowing the separation of the experiments in two groups}
  \item{sn.value}{indicates the threshold for S/N ratio to be considered significant. 3 indicate a 99.9 confidence that the signal is different from bg}
  \item{p}{indicates the percentage of experiments characterized by a specific sn value}
  \item{iqr.value}{indicates the IQR threshold }

}
\value{
  An object of class "applera".
}
\author{Raffaele A. Calogero <raffaele.calogero@unito.it>; Francesca cordero <fcordero@di.unito.it>}
\seealso{\code{\link{applera-class}} for the class of the return value.
}
\examples{
#tmp.1 <- optFilter(test, "wk" , sn.value=3, p=c(1, 0.75, 0.5, 0.25), iqr.value=c(0.5, 0.25))
}
\keyword{misc}
